@@ -1,4 +1,4 @@
-IndexUpdate = function(price, index.weights, divisor) {
+indexUpdate = function(price, index.weights, divisor) {
   index_value = sum(price * index.weights) / divisor
   return(index_value)
 }
\ No newline at end of file
